Clazz.declarePackage("JU");
Clazz.load(["java.io.IOException"], "JU.GZIPException", null, function(){
var c$ = Clazz.declareType(JU, "GZIPException", java.io.IOException);
});
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
